@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 
 # Copyright 2012 Yao-Po Wang <blue119@gmail.com>
 # Copyright 2013 Jaap Karssenberg <jaap.karssenberg@gmail.com>
@@ -25,22 +24,22 @@ info = {
 class Dumper(TextDumper):
 
 	BULLETS = {
-		UNCHECKED_BOX:	u'- \u2610', # ☐
-		XCHECKED_BOX:	u'- \u2612', # ☒
-		CHECKED_BOX:	u'- \u2611', # ☑
-		MIGRATED_BOX:	u'- \u25B7', # ▷
-		BULLET:		u'-',
+		UNCHECKED_BOX: '- \u2610',
+		XCHECKED_BOX: '- \u2612',
+		CHECKED_BOX: '- \u2611',
+		MIGRATED_BOX: '- \u25B7',
+		BULLET: '-',
 	}
 
 	TAGS = {
-		EMPHASIS:	('*', '*'),
-		STRONG:		('**', '**'),
-		MARK:		('', ''), # TODO, no directly way to do this in rst
-		STRIKE:		('', ''), # TODO, no directly way to do this in rst
-		VERBATIM:	("``", "``"),
-		TAG:		('', ''), # No additional annotation (apart from the visible @)
-		SUBSCRIPT:	('\\ :sub:`', '`\\ '),
-		SUPERSCRIPT:	('\\ :sup:`', '`\\ '),
+		EMPHASIS: ('*', '*'),
+		STRONG: ('**', '**'),
+		MARK: ('', ''), # TODO, no directly way to do this in rst
+		STRIKE: ('', ''), # TODO, no directly way to do this in rst
+		VERBATIM: ("``", "``"),
+		TAG: ('', ''), # No additional annotation (apart from the visible @)
+		SUBSCRIPT: ('\\ :sub:`', '`\\ '),
+		SUPERSCRIPT: ('\\ :sup:`', '`\\ '),
 	}
 	# TODO tags other than :sub: and :sup: may also need surrounding whitespace, deal with this in post process (join) action ?
 	# IDEM for blocks like images and objects, how to enforce empty lines and how to deal with inline images..
@@ -54,10 +53,12 @@ class Dumper(TextDumper):
 	def dump_h(self, tag, attrib, strings):
 		# Underlined headings
 		level = int(attrib['level'])
-		if level < 1:   level = 1
-		elif level > 4: level = 4
-		char = self.HEADING_UNDERLINE[level-1]
-		heading = u''.join(strings)
+		if level < 1:
+			level = 1
+		elif level > 4:
+			level = 4
+		char = self.HEADING_UNDERLINE[level - 1]
+		heading = ''.join(strings)
 		underline = char * len(heading)
 		return [heading + '\n', underline]
 
@@ -73,15 +74,14 @@ class Dumper(TextDumper):
 		assert 'href' in attrib, \
 			'BUG: link misses href: %s "%s"' % (attrib, strings)
 		href = self.linker.link(attrib['href'])
-		text = u''.join(strings) or href
+		text = ''.join(strings) or href
 		return '`%s <%s>`_' % (text, href)
 
 	def dump_img(self, tag, attrib, strings=None):
 		src = self.linker.img(attrib['src'])
 		text = '.. image:: %s\n' % src
 
-		items = attrib.items()
-		items.sort() # unit tests don't like random output
+		items = sorted(attrib.items())
 		for k, v in items:
 			if k == 'src' or k.startswith('_'):
 				continue
@@ -112,15 +112,15 @@ class Dumper(TextDumper):
 			table += [rowline(line) for line in row]
 			table.append(rowsep('-'))
 
-		return map(lambda line: line+"\n", table)
+		return [line + "\n" for line in table]
 
 	def dump_th(self, tag, attrib, strings):
-		strings = [s.replace('|', '∣') for s in strings]
+		#strings = [s.replace('|', '\u2223') for s in strings]
 		return [self._concat(strings)]
 
 	def dump_td(self, tag, attrib, strings):
-		strings = [s.replace('|', '∣') for s in strings]
+		#strings = [s.replace('|', '\u2223') for s in strings]
 		return [self._concat(strings)]
 
 	def dump_line(self, tag, attrib, strings=None):
-		return '\n{}\n'.format('*'*5)
+		return '\n{}\n'.format('*' * 5)
